==> wetkit-7.x-1.5-core.tar.gz: wetkit-7.x-1.5/profiles/wetkit/libraries/wet-boew/README.md <==
# Web Experience Toolkit (WET)

[![Build Status](https://secure.travis-ci.org/wet-boew/wet-boew.png?branch=v3.1)](http://travis-ci.org/wet-boew/wet-boew)

## What is the Web Experience Toolkit?

* Collaborative open source project led by the Government of Canada
* [Award-winning](http://wet-boew.github.io/v3.1-ci/docs/ref/accolades-en.html#awards) code library for building innovative websites that are:
 * [Accessible](#accessibility), [usable](#usability) and [interoperable](#interoperability)
 * [Mobile friendly](#mobile-friendly-responsive-design)
 * [Multilingual](#multilingual)
* [Flexible and themeable templates and reusable components](#themeable-and-reusable)
* Open source software
 * Free to use for commercial and non-commercial purposes (MIT license - [Terms and conditions](http://wet-boew.github.io/wet-boew/License-en.html))
 * [Developed openly by the community on GitHub](#collaborative-approach)

## Key resources

* [Benefits](#benefits)
* [Working examples](http://wet-boew.github.io/v3.1-ci/demos/index-en.html)
* [Working examples - v4.0](http://wet-boew.github.io/v4.0-ci/demos/index-en.html)
* [Documentation](http://wet-boew.github.io/v3.1-ci/docs/index-en.html)
* [Downloads](http://wet-boew.github.io/v3.1-ci/docs/versions/dwnld-en.html)
* [Main project](https://github.com/wet-boew/wet-boew/)
* [Terms and conditions](http://wet-boew.github.io/wet-boew/License-en.html)
* [Contributor guidelines](http://wet-boew.github.io/v3.1-ci/docs/gs-cd/contrib-en.html)
* [Versioning](http://wet-boew.github.io/v3.1-ci/docs/versions/version-info-en.html)
* [Version history](http://wet-boew.github.io/v3.1-ci/docs/versions/index-en.html)
* [Roadmap](http://wet-boew.github.io/v3.1-ci/docs/versions/rdmp-en.html)
* [Communications material](http://wet-boew.github.io/v3.1-ci/docs/index-en.html#comms)

## Benefits

### Accessibility 

* Conforms to [WCAG 2.0](http://www.w3.org/TR/WCAG20/) level AA
* Leverages [WAI-ARIA](http://www.w3.org/TR/wai-aria/) to further enhance accessibility
* Assistive technology testing (Access Working Group)

### Usability

* Iterative approach to design
* Design patterns and usability testing (User Experience Working Group)

### Interoperability

* [HTML5](http://www.w3.org/TR/html5/)-first approach (leveraging native HTML5 support and filling support gaps with “polyfills”)
* Supporting a wide variety of browsers (IE, Firefox, Chrome, Safari, Opera)
* Building support for HTML data ([RDFa 1.1 Lite](http://www.w3.org/TR/rdfa-lite/), [Schema.org](http://www.schema.org/))

### Mobile friendly responsive design

* Adapts to different screen sizes and device capabilities
* Touchscreen support ([jQuery Mobile](http://www.jquerymobile.com))
* Optimized for performance
* Building support for device-based mobile applications

### Multilingual

* Currently supports 33 languages (including right-to-left languages)
 * English
 * French
 * Afrikaans
 * Albanian
 * Arabic
 * Armenian
 * Bulgarian
 * Chinese
 * Chinese (Simplified)
 * Czech
 * Dutch
 * Estonian
 * German
 * Greek
 * Hindi
 * Hungarian
 * Icelandic
 * Indonesian
 * Italian
 * Japanese
 * Korean
 * Latvian
 * Lithuanian
 * Polish
 * Portuguese
 * Portuguese (Brazilian)
 * Russian
 * Slovak
 * Spanish
 * Thai
 * Turkish
 * Ukranian
 * Vietnamese

### Themeable and reusable

* Flexible framework that supports custom themes
* Includes support for 5 different themes including a “Base” theme to use as a template
* Reusable templates, plugins and widgets
* Adapted to various CMS and programming frameworks (Drupal, WordPress, SharePoint (in development), DotNetNuke (in development), PHP, SSI, Java/Maven)

### Reduces costs by openly sharing and collaborating

* Drives down research and development costs
* Avoids duplication of effort
* Produces better quality results

### Collaborative approach

* Project managed openly on GitHub, including discussion through the issues tracker
* Encouraging a free flow of ideas, dialogue and innovation including sharing of challenges and ideas
* External contributions welcome
 * Pull requests
 * Design patterns
 * Issues and suggestions
 * Documentation
 * Testing
* Multi-level review process for contributions to ensure code integrity (combination of automated and manual reviews)

-------------------------------------------------------------------

# Boîte à outils de l’expérience Web (BOEW)

## Qu’est-ce que la Boîte à outils de l’expérience Web?

* Un projet à source ouverte collaboratif dirigé par le Gouvernement du Canada
* Une bibliothèque de code [primée](http://wet-boew.github.io/v3.1-ci/docs/ref/accolades-fr.html#primes) pour construire des sites Web innovants&#160;:
 * [Accessibles](#accessibilit), [faciles d'emploi](#facilit-demploi) et [interopérables](#interoprabilit)
 * [Optimisés pour les appareils mobiles](#conception-optimise-pour-les-appareils-mobiles-et-ractive)
 * [Multilingues](#multilingue)
* [Des modèles, ainsi que des composants réutilisables, qui sont flexibles et personnalisables](#personnalisable-et-rutilisable)
* Un logiciel libre
 * Libre d'utilisation à des fins commerciales et non commerciales (licence MIT - [Conditions régissant l'utilisation](http://wet-boew.github.io/wet-boew/Licence-fr.html))
 * [Développé ouvertement sur GitHub par la communauté](#approche-collaborative)

## Ressources clés
 
* [Avantages](#avantages)
* [Exemples pratiques](http://wet-boew.github.io/v3.1-ci/demos/index-fr.html)
* [Exemples pratiques - v4.0](http://wet-boew.github.io/v4.0-ci/demos/index-fr.html)
* [Documentation](http://wet-boew.github.io/v3.1-ci/docs/index-fr.html)
* [Téléchargements](http://wet-boew.github.io/v3.1-ci/docs/versions/dwnld-fr.html)
* [Projet principal](https://github.com/wet-boew/wet-boew/)
* [Conditions régissant l'utilisation](http://wet-boew.github.io/wet-boew/Licence-fr.html)
* [Lignes directrices pour les contributeurs](http://wet-boew.github.io/v3.1-ci/docs/gs-cd/contrib-fr.html)
* [Contrôle des versions](http://wet-boew.github.io/v3.1-ci/docs/versions/version-info-fr.html)
* [Historique des versions](http://wet-boew.github.io/v3.1-ci/docs/versions/index-fr.html)
* [Feuille de route](http://wet-boew.github.io/v3.1-ci/docs/versions/rdmp-fr.html)
* [Matériel de communications](http://wet-boew.github.io/v3.1-ci/docs/index-fr.html#comms)

## Avantages

### Accessibilité

* •	Conforme aux [Règles pour l'accessibilité des contenus Web (WCAG) 2.0](http://www.w3.org/Translations/WCAG20-fr/) niveau AA
* S'appuie sur [WAI-ARIA](http://www.w3.org/TR/wai-aria/) pour améliorer l'accessibilité
* Vérification avec les technologies d'assistance (Groupe de travail sur l'accessibilité)

### Facilité d'emploi

* Approche itérative pour la conception
* Patrons de conception et les essais de facilité d'emploi (Groupe de travail sur l'expérience des utilisateurs)

### Interopérabilité

* Approche centrée sur le [HTML5](http://www.w3.org/TR/html5/) (s'appuyant sur le soutien HTML5 natif et puis les &laquo;correctifs&raquo; pour résoudre les problèmes de soutien)
* Soutien pour plusieurs navigateurs (IE, Firefox, Chrome, Safari, Opera)
* Soutien en développement pour les données HTML ([RDFa 1.1 Lite](http://www.w3.org/TR/rdfa-lite/), [Schema.org](http://www.schema.org/))

### Conception optimisée pour les appareils mobiles et réactive

* S'adapte à différentes tailles d'écran et capacités d'appareil
* Soutien pour les écrans tactiles ([jQuery Mobile](http://www.jquerymobile.com))
* Optimisé pour les performances
* Soutien en développement pour les applications s’installant sur un appareil mobile

### Multilingue

* Soutien actuellement 33 langues (y compris les langues droite-à-gauche)
 * Anglais
 * Français
 * Afrikaans
 * Albanais
 * Allemand
 * Arabe
 * Arménien
 * Bulgare
 * Chinois
 * Chinois (simplifiée)
 * Coréen
 * Espagnol
 * Estonien
 * Grec
 * Hindi
 * Hongrois
 * Indonésien
 * Islandais
 * Italien
 * Japonais
 * Letton
 * Lituanien
 * Néerlandais
 * Polonais
 * Portugais
 * Portugais (brésilien)
 * Russe
 * Slovaque
 * Tchèque
 * Thaï
 * Turc
 * Ukrainien
 * Vietnamien

### Personnalisable et réutilisable

* Cadre flexible qui supporte des thèmes personnalisés
* Soutien 5 thèmes différents, y compris un thème de base servant comme modèle
* Modèles, plugiciels et gadgets réutilisables
* Adapté aux différents systèmes de gestion de contenu et cadres de programmation (Drupal, WordPress, SharePoint (en développement), DotNetNuke (en développement), PHP, SSI, Java/Maven)

### Réduit les coûts en partageant et en collaborant ouvertement

* Réduit les coûts de recherche et de développement
* Évite la duplication des efforts
* Produit des résultats de meilleure qualité

### Approche collaborative

* Projet géré ouvertement sur GitHub, y compris les discussions à travers le système de suivi des questions
* Encourage la libre circulation des idées, du dialogue et de l'innovation, y compris le partage des défis et des idées
* Les contributions externes sont invités
 * Soumissions de code
 * Patrons de conception
 * Problèmes et suggestions
 * Documentation
 * Évaluations
* Processus d'examen sur plusieurs niveaux pour les contributions pour assurer l'intégrité du code (combinaison d'évaluations automatisées et manuelles)

==> wetkit-7.x-1.15-core.tar.gz: wetkit-7.x-1.15/profiles/wetkit/libraries/wet-boew/README.md <==
# Web Experience Toolkit (WET)

[![Build Status](https://secure.travis-ci.org/wet-boew/wet-boew.png?branch=v3.1)](http://travis-ci.org/wet-boew/wet-boew)

## What is the Web Experience Toolkit?

* Collaborative open source project led by the Government of Canada
* [Award-winning](http://wet-boew.github.io/wet-boew-legacy/v3.1/docs/ref/accolades-en.html#awards) code library for building innovative websites that are:
 * [Accessible](#accessibility), [usable](#usability) and [interoperable](#interoperability)
 * [Mobile friendly](#mobile-friendly-responsive-design)
 * [Multilingual](#multilingual)
* [Flexible and themeable templates and reusable components](#themeable-and-reusable)
* Open source software
 * Free to use for commercial and non-commercial purposes (MIT license - [Terms and conditions](http://wet-boew.github.io/wet-boew/License-en.html))
 * [Developed openly by the community on GitHub](#collaborative-approach)

## Key resources

* [Benefits](#benefits)
* [Working examples](http://wet-boew.github.io/wet-boew-legacy/v3.1/demos/index-en.html)
* [Working examples - v4.0](http://wet-boew.github.io/v4.0-ci/demos/index-en.html)
* [Documentation](http://wet-boew.github.io/wet-boew-legacy/v3.1/docs/index-en.html)
* [Downloads](http://wet-boew.github.io/wet-boew-legacy/v3.1/docs/versions/dwnld-en.html)
* [Main project](https://github.com/wet-boew/wet-boew/)
* [Terms and conditions](http://wet-boew.github.io/wet-boew/License-en.html)
* [Contributor guidelines](http://wet-boew.github.io/wet-boew-legacy/v3.1/docs/gs-cd/contrib-en.html)
* [Versioning](http://wet-boew.github.io/wet-boew-legacy/v3.1/docs/versions/version-info-en.html)
* [Version history](http://wet-boew.github.io/wet-boew-legacy/v3.1/docs/versions/index-en.html)
* [Roadmap](http://wet-boew.github.io/wet-boew-legacy/v3.1/docs/versions/rdmp-en.html)
* [Communications material](http://wet-boew.github.io/wet-boew-legacy/v3.1/docs/index-en.html#comms)

## Benefits

### Accessibility

* Conforms to [WCAG 2.0](http://www.w3.org/TR/WCAG20/) level AA
* Leverages [WAI-ARIA](http://www.w3.org/TR/wai-aria/) to further enhance accessibility
* Assistive technology testing (Access Working Group)

### Usability

* Iterative approach to design
* Design patterns and usability testing (User Experience Working Group)

### Interoperability

* [HTML5](http://www.w3.org/TR/html5/)-first approach (leveraging native HTML5 support and filling support gaps with “polyfills”)
* Supporting a wide variety of browsers (IE, Firefox, Chrome, Safari, Opera)
* Building support for HTML data ([RDFa 1.1 Lite](http://www.w3.org/TR/rdfa-lite/), [Schema.org](http://www.schema.org/))

### Mobile friendly responsive design

* Adapts to different screen sizes and device capabilities
* Touchscreen support ([jQuery Mobile](http://www.jquerymobile.com))
* Optimized for performance
* Building support for device-based mobile applications

### Multilingual

* Currently supports 33 languages (including right-to-left languages)
 * English
 * French
 * Afrikaans
 * Albanian
 * Arabic
 * Armenian
 * Bulgarian
 * Chinese
 * Chinese (Simplified)
 * Czech
 * Dutch
 * Estonian
 * German
 * Greek
 * Hindi
 * Hungarian
 * Icelandic
 * Indonesian
 * Italian
 * Japanese
 * Korean
 * Latvian
 * Lithuanian
 * Polish
 * Portuguese
 * Portuguese (Brazilian)
 * Russian
 * Slovak
 * Spanish
 * Thai
 * Turkish
 * Ukranian
 * Vietnamese

### Themeable and reusable

* Flexible framework that supports custom themes
* Includes support for 5 different themes including a “Base” theme to use as a template
* Reusable templates, plugins and widgets
* Adapted to various CMS and programming frameworks (Drupal, WordPress, SharePoint (in development), DotNetNuke (in development), PHP, SSI, Java/Maven)

### Reduces costs by openly sharing and collaborating

* Drives down research and development costs
* Avoids duplication of effort
* Produces better quality results

### Collaborative approach

* Project managed openly on GitHub, including discussion through the issues tracker
* Encouraging a free flow of ideas, dialogue and innovation including sharing of challenges and ideas
* External contributions welcome
 * Pull requests
 * Design patterns
 * Issues and suggestions
 * Documentation
 * Testing
* Multi-level review process for contributions to ensure code integrity (combination of automated and manual reviews)

-------------------------------------------------------------------

# Boîte à outils de l’expérience Web (BOEW)

## Qu’est-ce que la Boîte à outils de l’expérience Web?

* Un projet à source ouverte collaboratif dirigé par le Gouvernement du Canada
* Une bibliothèque de code [primée](http://wet-boew.github.io/wet-boew-legacy/v3.1/docs/ref/accolades-fr.html#primes) pour construire des sites Web innovants&#160;:
 * [Accessibles](#accessibilit), [faciles d'emploi](#facilit-demploi) et [interopérables](#interoprabilit)
 * [Optimisés pour les appareils mobiles](#conception-optimise-pour-les-appareils-mobiles-et-ractive)
 * [Multilingues](#multilingue)
* [Des modèles, ainsi que des composants réutilisables, qui sont flexibles et personnalisables](#personnalisable-et-rutilisable)
* Un logiciel libre
 * Libre d'utilisation à des fins commerciales et non commerciales (licence MIT - [Conditions régissant l'utilisation](http://wet-boew.github.io/wet-boew/Licence-fr.html))
 * [Développé ouvertement sur GitHub par la communauté](#approche-collaborative)

## Ressources clés

* [Avantages](#avantages)
* [Exemples pratiques](http://wet-boew.github.io/wet-boew-legacy/v3.1/demos/index-fr.html)
* [Exemples pratiques - v4.0](http://wet-boew.github.io/v4.0-ci/demos/index-fr.html)
* [Documentation](http://wet-boew.github.io/wet-boew-legacy/v3.1/docs/index-fr.html)
* [Téléchargements](http://wet-boew.github.io/wet-boew-legacy/v3.1/docs/versions/dwnld-fr.html)
* [Projet principal](https://github.com/wet-boew/wet-boew/)
* [Conditions régissant l'utilisation](http://wet-boew.github.io/wet-boew/Licence-fr.html)
* [Lignes directrices pour les contributeurs](http://wet-boew.github.io/wet-boew-legacy/v3.1/docs/gs-cd/contrib-fr.html)
* [Contrôle des versions](http://wet-boew.github.io/wet-boew-legacy/v3.1/docs/versions/version-info-fr.html)
* [Historique des versions](http://wet-boew.github.io/wet-boew-legacy/v3.1/docs/versions/index-fr.html)
* [Feuille de route](http://wet-boew.github.io/wet-boew-legacy/v3.1/docs/versions/rdmp-fr.html)
* [Matériel de communications](http://wet-boew.github.io/wet-boew-legacy/v3.1/docs/index-fr.html#comms)

## Avantages

### Accessibilité

* •	Conforme aux [Règles pour l'accessibilité des contenus Web (WCAG) 2.0](http://www.w3.org/Translations/WCAG20-fr/) niveau AA
* S'appuie sur [WAI-ARIA](http://www.w3.org/TR/wai-aria/) pour améliorer l'accessibilité
* Vérification avec les technologies d'assistance (Groupe de travail sur l'accessibilité)

### Facilité d'emploi

* Approche itérative pour la conception
* Patrons de conception et les essais de facilité d'emploi (Groupe de travail sur l'expérience des utilisateurs)

### Interopérabilité

* Approche centrée sur le [HTML5](http://www.w3.org/TR/html5/) (s'appuyant sur le soutien HTML5 natif et puis les &laquo;correctifs&raquo; pour résoudre les problèmes de soutien)
* Soutien pour plusieurs navigateurs (IE, Firefox, Chrome, Safari, Opera)
* Soutien en développement pour les données HTML ([RDFa 1.1 Lite](http://www.w3.org/TR/rdfa-lite/), [Schema.org](http://www.schema.org/))

### Conception optimisée pour les appareils mobiles et réactive

* S'adapte à différentes tailles d'écran et capacités d'appareil
* Soutien pour les écrans tactiles ([jQuery Mobile](http://www.jquerymobile.com))
* Optimisé pour les performances
* Soutien en développement pour les applications s’installant sur un appareil mobile

### Multilingue

* Soutien actuellement 33 langues (y compris les langues droite-à-gauche)
 * Anglais
 * Français
 * Afrikaans
 * Albanais
 * Allemand
 * Arabe
 * Arménien
 * Bulgare
 * Chinois
 * Chinois (simplifiée)
 * Coréen
 * Espagnol
 * Estonien
 * Grec
 * Hindi
 * Hongrois
 * Indonésien
 * Islandais
 * Italien
 * Japonais
 * Letton
 * Lituanien
 * Néerlandais
 * Polonais
 * Portugais
 * Portugais (brésilien)
 * Russe
 * Slovaque
 * Tchèque
 * Thaï
 * Turc
 * Ukrainien
 * Vietnamien

### Personnalisable et réutilisable

* Cadre flexible qui supporte des thèmes personnalisés
* Soutien 5 thèmes différents, y compris un thème de base servant comme modèle
* Modèles, plugiciels et gadgets réutilisables
* Adapté aux différents systèmes de gestion de contenu et cadres de programmation (Drupal, WordPress, SharePoint (en développement), DotNetNuke (en développement), PHP, SSI, Java/Maven)

### Réduit les coûts en partageant et en collaborant ouvertement

* Réduit les coûts de recherche et de développement
* Évite la duplication des efforts
* Produit des résultats de meilleure qualité

### Approche collaborative

* Projet géré ouvertement sur GitHub, y compris les discussions à travers le système de suivi des questions
* Encourage la libre circulation des idées, du dialogue et de l'innovation, y compris le partage des défis et des idées
* Les contributions externes sont invités
 * Soumissions de code
 * Patrons de conception
 * Problèmes et suggestions
 * Documentation
 * Évaluations
* Processus d'examen sur plusieurs niveaux pour les contributions pour assurer l'intégrité du code (combinaison d'évaluations automatisées et manuelles)
